@@ -11,8 +11,12 @@ def IsSpecificPythonTool(toml_file_path: str, tool_name:str):
     return False
 
 def IsFileFlit(toml_file_path: str) -> bool:
-    toml_loaded: MutableMapping[str,Any]=toml.load(toml_file_path)
-    return toml_loaded["project"].keys().__contains__("dependencies")
+    # temporary solution
+    try:
+        toml_loaded: MutableMapping[str,Any]=toml.load(toml_file_path)
+        return toml_loaded["project"].keys().__contains__("dependencies")
+    except:
+        return IsSpecificPythonTool(toml_file_path,"flit")
 
 def IsFilePoetry(toml_file_path: str) -> bool:
     return IsSpecificPythonTool(toml_file_path,"poetry")
@@ -28,4 +32,4 @@ def IsFileJuliaPkg(toml_file_path: str) -> bool:
     """
     Julia's pkg tool uses Project.toml file.
     """
-    return pathlib.Path(toml_file_path).name == "Project.toml"
\ No newline at end of file
+    return pathlib.Path(toml_file_path).name == "Project.toml"
